@define-color polari_dark_bg_color shade(@theme_bg_color, 0.95);

.polari-sidebar {
    border-style: solid;
    border-color: @borders;
    border-image: none;
}

.polari-sidebar.polari-room-list:dir(ltr) {
    border-width: 0 1px 0 0;
}

.polari-sidebar.polari-room-list:dir(rtl) {
    border-width: 0 0 0 1px;
}

.polari-user-list .list-row {
    -GtkWidget-focus-padding: 0;
}

.polari-user-list .list-row.expanded {
    background-color: @content_view_bg;
}

.polari-user-list .list-row GtkFrame {
    box-shadow: inset 0 2px 4px alpha(@polari_dark_bg_color, 0.8);
    transition: all 250ms ease-out;
    border-width: 0;
}

.polari-room-list .action-bar,
.polari-input-area {
    background-image: none;
    background-color: @polari_dark_bg_color;
    border-color: @borders;
    border-style: solid;
    border-width: 1px 0 0 0;
}

.polari-nick-entry {
    color: alpha(@theme_fg_color, 0.6);
}

.polari-room-list .room-list-header {
    background-color: @polari_dark_bg_color;
    font-size: smaller;
    padding: 2px 6px;
}

.polari-room-list .list-row.inactive {
    color: mix(@theme_fg_color, @theme_base_color, 0.3);
}

.polari-room-list .list-row.inactive:selected {
    color: mix(@theme_selected_fg_color, @theme_base_color, 0.3);
}

.polari-room-list .list-row.inactive:backdrop {
    color: mix(@theme_unfocused_fg_color, @theme_unfocused_base_color, 0.3);
}

.polari-room-list .list-row.inactive:selected:backdrop {
    color: @theme_unfocused_selected_fg_color;
}

.polari-room-list .list-row .pending-messages-count {
    color: @theme_selected_fg_color;
    background-color: mix(@theme_selected_bg_color, @theme_selected_fg_color, 0.3);
    font-size: smaller;
    border-radius: 4px;
    padding: 0px 4px;
}

.polari-room-list .list-row .pending-messages-count:backdrop {
    color: @theme_unfocused_selected_fg_color;
    background-color: mix(@theme_unfocused_selected_bg_color, @theme_unfocused_selected_fg_color, 0.1);
}

.irc-feedback {
    color: @theme_fg_color;
    background-color: @theme_bg_color;
    border-style: solid;
    border-color: @borders;
    border-width: 1px 1px 0 1px;
    border-radius: 6px 6px 0 0;
    padding: 6px;
}

.polari-titlebar-left {
    /* the horizontal padding confuses left_side_size_group, so we
       add it as margin-left to the first button instead (in mainWindow.ui);
       also set the vertical padding to 0 so the separator extends to the
       bottom */
    padding: 0 1px;
}

.polari-titlebar-left:dir(ltr),
.polari-titlebar-right:dir(rtl) {
    border-top-right-radius: 0;
}

.polari-titlebar-right:dir(ltr),
.polari-titlebar-left:dir(rtl) {
    border-top-left-radius: 0;
}

.polari-titlebar-separator {
    border-image: linear-gradient(to bottom, @theme_bg_color, shade(@borders, 1.2));
    border-image-width: 0 1px 0 0;
    border-image-slice: 1;
}

.polari-titlebar-separator:backdrop {
    border-image: none;
    border-color: transparent;
}

.polari-user-list-button {
    padding: 0px 4px;
}
